#
# spec file for package gnome-console
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-console
Version:        48.0.1
Release:        2.1
Summary:        A minimal terminal for GNOME
License:        GPL-3.0-only
URL:            https://gitlab.gnome.org/GNOME/console
Source:         %{name}-%{version}.tar.zst

BuildRequires:  AppStream
BuildRequires:  c_compiler
BuildRequires:  desktop-file-utils
BuildRequires:  libxml2-tools
BuildRequires:  meson >= 0.59.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.76
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.76
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gtk4) >= 4.12.2
BuildRequires:  pkgconfig(libadwaita-1) >= 1.4.alpha
BuildRequires:  pkgconfig(libgtop-2.0)
BuildRequires:  pkgconfig(libpcre2-8) >= 10.32
BuildRequires:  pkgconfig(vte-2.91-gtk4) >= 0.77.0

Obsoletes:      nautilus-extension-console < %{version}
Provides:       console = %{version}
Provides:       nautilus-extension-console = %{version}
Obsoletes:      console < 45.0

%description
Console is supposed to be a simple terminal emulator for the average
user to carry out simple cli tasks.
However, it is not trying to replace GNOME Terminal/Tilix; these
advanced tools are great for developers and administrators.
GNOME console rather aims to serve the casual linux user who rarely
needs a terminal.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D tests=true \
	%{nil}
%meson_build

%install
%meson_install
%find_lang kgx %{?no_lang_C} %{name}.lang

%check
%meson_test

%files
%license COPYING
%doc README.md
%{_bindir}/kgx
%{_datadir}/applications/org.gnome.Console.desktop
%{_datadir}/dbus-1/services/org.gnome.Console.service
%{_datadir}/glib-2.0/schemas/org.gnome.Console.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Console.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Console-symbolic.svg
%{_datadir}/metainfo/org.gnome.Console.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Sun Mar 30 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Replace appstream-glib with AppStream BuildRequires, use the
  correct dependency, and pass tests=true to meson setup, run all
  the tests available.
* Sun Mar 16 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.0.1:
  + Updated translations.
* Sun Mar  9 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.rc:
  + We have kept up with some changes in Adwaita, modernised some
    of our metadata, and continued chasing those bugs and filing
    the rough edges.
  + Updated translations.
* Wed Sep 18 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.1:
  + Some minor build issues on certain platforms have been ironed
    out.
* Wed Sep 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 47.0+5:
  + Fix build on 32bit architectures (glgo#GNOME/console#391).
* Sun Sep 15 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + A edge case in drag-and-drop has been resolved.
  + Fixed a string that hadn't been marked for translation.
  + Updated translations.
* Mon Sep  2 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.rc:
  + A couple small improvements.
  + Updated translations.
* Tue Aug 20 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.beta:
  + The preferences dialogue has been expanded to include
    scrollback size, and there has been behind the scenes work
    fixing some pesky issues and setting up future improvements.
  + Thanks to work elsewhere in the stack, we now have restored
    screen reader support. This has taken far too long, and there
    is more work do be done, but hopefully this is a significant
    step forward.
  + Additionally reworked our styles to take advantage of
    improvements in Gtk, and keep current with developments in
    Adwaita, and some more fixes.
  + Updated translations.
* Tue Mar 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Updated translations.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + Various of our dialogues have been reworked to improve
    correctness, including how they handle especially long strings.
  + When restoring window dimensions we now remember if the window
    was maximised or not, windows also now avoid the ‘duplicated
    effect’ seen with certain shell setups.
  + We continue to take advantage of newer Vte features wherever
    appropriate.
- Drop d259c18bc21ad83381e990b48bc66ea1dec21528.patch: fixed
  upstream.
* Mon Nov  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Sun Oct 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add d259c18bc21ad83381e990b48bc66ea1dec21528.patch: close-dialog:
  clamp row title to maximum length.
* Mon Sep 25 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Inital packaging under the name gnome-console for openSUSE.
